ChimeSession class

A ChangeNotifier that holds the state of a single Chime meeting session and exposes actions that proxy to AmazonChime.instance.

This is an opt-in convenience for apps using package:provider. Apps using BLoC, Riverpod, or any other state solution can ignore this class and wire the raw Streams and Future-returning methods on AmazonChime.instance into their own state containers.

Inheritance
Mixed-in types

Constructors

ChimeSession()

Properties

activeCameraFacing String?
no setter
activeSpeakers List<String>
no setter
allParticipants List<Attendee>
no setter
contentAttendeeId String?
no setter
currAttendees Map<String, Attendee>
no setter
deviceList List<String>
no setter
hasContentAttendee bool
no setter
hasContentVideoTile bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
hasLocalAttendee bool
no setter
hasRemoteAttendees bool
no setter
isConnectionPoor bool
no setter
isLocalMuted bool
no setter
isLocalScreenSharing bool
no setter
isLocalVideoOn bool
no setter
isMeetingActive bool
no setter
isReceivingScreenShare bool
no setter
isReconnecting bool
no setter
localAttendee Attendee?
no setter
localAttendeeId String?
no setter
participantCount int
no setter
remoteAttendeeIds List<String>
no setter
remoteAttendees List<Attendee>
no setter
roster Map<String, String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedAudioDevice String?
no setter
shouldShowLocalVideo bool
no setter
shouldShowScreenShare bool
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
didChangeAccessibilityFeatures() → void
Called when the system changes the set of currently active accessibility features.
inherited
didChangeAppLifecycleState(AppLifecycleState state) → void
Called when the system puts the app in the background or returns the app to the foreground.
override
didChangeLocales(List<Locale>? locales) → void
Called when the system tells the app that the user's locale has changed. For example, if the user changes the system language settings.
inherited
didChangeMetrics() → void
Called when the application's dimensions change. For example, when a phone is rotated.
inherited
didChangePlatformBrightness() → void
Called when the platform brightness changes.
inherited
didChangeTextScaleFactor() → void
Called when the platform's text scale factor changes.
inherited
didChangeViewFocus(ViewFocusEvent event) → void
Called whenever the PlatformDispatcher receives a notification that the focus state on a view has changed.
inherited
didHaveMemoryPressure() → void
Called when the system is running low on memory.
inherited
didPopRoute() Future<bool>
Called when the system tells the app to pop the current route, such as after a system back button press or back gesture.
inherited
didPushRoute(String route) Future<bool>
Called when the host tells the application to push a new route onto the navigator.
inherited
didPushRouteInformation(RouteInformation routeInformation) Future<bool>
Called when the host tells the application to push a new RouteInformation and a restoration state onto the router.
inherited
didRequestAppExit() Future<AppExitResponse>
Called when a request is received from the system to exit the application.
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
override
handleCancelBackGesture() → void
Called when a predictive back gesture is canceled, indicating that no navigation should occur.
inherited
handleCommitBackGesture() → void
Called when a predictive back gesture is finished successfully, indicating that the current route should be popped.
inherited
handleStartBackGesture(PredictiveBackEvent backEvent) bool
Called at the start of a predictive back gesture.
inherited
handleStatusBarTap() → void
Called when the user taps the status bar on iOS, to scroll a scroll view to the top.
inherited
handleUpdateBackGestureProgress(PredictiveBackEvent backEvent) → void
Called when a predictive back gesture moves.
inherited
initialAudioSelection() Future<void>
initializeMeeting({required JoinInfo joinInfo, required Map<String, String> roster}) → void
isActiveSpeaker(String attendeeId) bool
listAudioDevices() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
sendLocalMuteToggle() Future<void>
sendLocalScreenShareToggle() Future<void>
sendLocalVideoTileOn() Future<void>
stopMeeting() Future<void>
switchCamera() Future<void>
Switches between front and back camera and refreshes activeCameraFacing.
toString() String
A string representation of this object.
inherited
updateCurrentDevice(String device) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited