DataMessage class

A real-time data message received from another attendee.

Constructors

DataMessage({required String topic, required String data, required String senderAttendeeId, required String senderExternalUserId, required int timestampMs, required bool throttled})
const

Properties

data String
The UTF-8 string payload.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderAttendeeId String
final
senderExternalUserId String
final
throttled bool
True if the message was throttled by the server.
final
timestampMs int
Server timestamp in milliseconds since epoch.
final
topic String
The topic/channel the message was sent on.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited