ChimeException class abstract

Base exception for all Amazon Chime SDK errors.

Implemented types
Implementers

Constructors

ChimeException(String message, [String? code])
const

Properties

code String?
Optional underlying error code or native platform details.
final
hashCode int
The hash code for this object.
no setterinherited
message String
A descriptive message for the error.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited