VideoTileInfo class
Represents an active video stream tile from the Amazon Chime SDK.
Constructors
- VideoTileInfo({required int tileId, required String attendeeId, required int videoStreamContentWidth, required int videoStreamContentHeight, required bool isLocalTile, })
-
const
- VideoTileInfo.fromJson(dynamic jsonMap)
-
factory
Properties
- attendeeId → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
final
- isLocalTile → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tileId → int
-
final
- videoStreamContentHeight → int
-
final
- videoStreamContentWidth → int
-
final
Methods
-
copyWith(
{int? tileId, String? attendeeId, int? videoStreamContentWidth, int? videoStreamContentHeight, bool? isLocalTile, }) → VideoTileInfo -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override