Style class

Constructors

Style()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

circleButton ButtonStyle
Circular button shape used by all meeting control buttons.
final
iconPadding double
getter/setter pair
iconSize double
getter/setter pair

Constants

buttonSize → const double
fontSize → const double
titleSize → const double