Attendee class
Represents a participant in an Amazon Chime meeting.
Constructors
- Attendee({required String attendeeId, required String externalUserId, bool muteStatus = false, bool isVideoOn = false, VideoTileInfo? videoTileInfo})
-
const
- Attendee.fromJson(dynamic jsonMap)
-
factory
Properties
- attendeeId → String
-
final
- externalUserId → String
-
final
- formattedExternalId → String
-
The human-readable portion of externalUserId.
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- isContent → bool
-
Whether this attendee represents a content share (screen share) source.
no setter
- isVideoOn → bool
-
final
- muteStatus → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- videoTileInfo → VideoTileInfo?
-
final
Methods
-
copyWith(
{String? attendeeId, String? externalUserId, bool? muteStatus, bool? isVideoOn, VideoTileInfo? videoTileInfo}) → Attendee -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeVideoTile(
) → Attendee -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
isContentId(
String? attendeeId) → bool -
Whether the given
attendeeIdstring represents a content share source.