AttendeeSignal class
Signal strength for a single attendee. signalStrength: 0=none, 1=low, 2=high
Constructors
- AttendeeSignal({required String attendeeId, required String externalUserId, required int signalStrength})
-
const
Properties
- attendeeId → String
-
final
- externalUserId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signalStrength → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited