AttendeeVolume class
Volume level for a single attendee. volume: 0=muted, 1=notSpeaking, 2=low, 3=medium, 4=high
Constructors
- AttendeeVolume({required String attendeeId, required String externalUserId, required int volume})
-
const
Properties
- attendeeId → String
-
final
- externalUserId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- volume → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited