ChimeMeetingException class
Thrown when starting, stopping, or joining a meeting fails.
- Inheritance
-
- Object
- ChimeException
- ChimeMeetingException
Constructors
- ChimeMeetingException(String message, [String? code])
-
const
Properties
- code → String?
-
Optional underlying error code or native platform details.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A descriptive message for the error.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited